<?php

/**
 * @license LGPLv3, http://opensource.org/licenses/LGPL-3.0
 * @copyright Metaways Infosystems GmbH, 2013
 * @copyright Aimeos (aimeos.org), 2014-2022
 * @package MShop
 * @subpackage Customer
 */


namespace Aimeos\MShop\Customer\Manager\Lists\Type;


/**
 * TYPO3 implementation of the customer list type class.
 *
 * @package MShop
 * @subpackage Customer
 */
class Typo3
	extends \Aimeos\MShop\Customer\Manager\Lists\Type\Standard
{
	private $searchConfig = array(
		'customer.lists.type.id' => array(
			'code' => 'customer.lists.type.id',
			'internalcode' => 'mcuslity."id"',
			'label' => 'Customer list type ID',
			'type'=> 'integer',
			'internaltype' => \Aimeos\Base\DB\Statement\Base::PARAM_INT,
			'public' => false,
		),
		'customer.lists.type.siteid' => array(
			'code' => 'customer.lists.type.siteid',
			'internalcode' => 'mcuslity."siteid"',
			'label' => 'Customer list type site ID',
			'type' => 'string',
			'internaltype' => \Aimeos\Base\DB\Statement\Base::PARAM_STR,
			'public' => false,
		),
		'customer.lists.type.code' => array(
			'code' => 'customer.lists.type.code',
			'internalcode' => 'mcuslity."code"',
			'label' => 'Customer list type code',
			'type'=> 'string',
			'internaltype' => \Aimeos\Base\DB\Statement\Base::PARAM_STR,
		),
		'customer.lists.type.domain' => array(
			'code' => 'customer.lists.type.domain',
			'internalcode' => 'mcuslity."domain"',
			'label' => 'Customer list type domain',
			'type'=> 'string',
			'internaltype' => \Aimeos\Base\DB\Statement\Base::PARAM_STR,
		),
		'customer.lists.type.label' => array(
			'code' => 'customer.lists.type.label',
			'internalcode' => 'mcuslity."label"',
			'label' => 'Customer list type label',
			'type'=> 'string',
			'internaltype' => \Aimeos\Base\DB\Statement\Base::PARAM_STR,
		),
		'customer.lists.type.position' => array(
			'code' => 'customer.lists.type.position',
			'internalcode' => 'mcuslity."pos"',
			'label' => 'Customer list type position',
			'type'=> 'integer',
			'internaltype' => \Aimeos\Base\DB\Statement\Base::PARAM_INT,
		),
		'customer.lists.type.status' => array(
			'code' => 'customer.lists.type.status',
			'internalcode' => 'mcuslity."status"',
			'label' => 'Customer list type status',
			'type'=> 'integer',
			'internaltype' => \Aimeos\Base\DB\Statement\Base::PARAM_INT,
		),
		'customer.lists.type.ctime'=> array(
			'code' => 'customer.lists.type.ctime',
			'internalcode' => 'mcuslity."ctime"',
			'label' => 'Customer list type create date/time',
			'type'=> 'datetime',
			'internaltype'=> \Aimeos\Base\DB\Statement\Base::PARAM_STR,
		),
		'customer.lists.type.mtime'=> array(
			'code' => 'customer.lists.type.mtime',
			'internalcode' => 'mcuslity."mtime"',
			'label' => 'Customer list type modification date/time',
			'type'=> 'datetime',
			'internaltype'=> \Aimeos\Base\DB\Statement\Base::PARAM_STR,
		),
		'customer.lists.type.editor'=> array(
			'code' => 'customer.lists.type.editor',
			'internalcode' => 'mcuslity."editor"',
			'label' => 'Customer list type editor',
			'type'=> 'string',
			'internaltype'=> \Aimeos\Base\DB\Statement\Base::PARAM_STR,
		),
	);


	/**
	 * Removes old entries from the storage.
	 *
	 * @param iterable $siteids List of IDs for sites whose entries should be deleted
	 * @return \Aimeos\MShop\Common\Manager\Iface Same object for fluent interface
	 */
	public function clear( iterable $siteids ) : \Aimeos\MShop\Common\Manager\Iface
	{
		$path = 'mshop/customer/manager/lists/type/submanagers';
		foreach( $this->context()->config()->get( $path, [] ) as $domain ) {
			$this->object()->getSubManager( $domain )->clear( $siteids );
		}

		return $this->clearBase( $siteids, 'mshop/customer/manager/lists/type/typo3/delete' );
	}


	/**
	 * Returns the attributes that can be used for searching.
	 *
	 * @param bool $withsub Return also attributes of sub-managers if true
	 * @return array Returns a list of attribtes implementing \Aimeos\Base\Criteria\Attribute\Iface
	 */
	public function getSearchAttributes( bool $withsub = true ) : array
	{
		$path = 'mshop/customer/manager/lists/type/submanagers';

		return $this->getSearchAttributesBase( $this->searchConfig, $path, [], $withsub );
	}


	/**
	 * Returns a new manager for customer extensions
	 *
	 * @param string $manager Name of the sub manager type in lower case
	 * @param string|null $name Name of the implementation, will be from configuration (or Default) if null
	 * @return mixed Manager for different extensions, e.g stock, tags, locations, etc.
	 */
	public function getSubManager( string $manager, string $name = null ) : \Aimeos\MShop\Common\Manager\Iface
	{
		return $this->getSubManagerBase( 'customer', 'lists/type/' . $manager, ( $name === null ? 'Typo3' : $name ) );
	}


	/**
	 * Returns the config path for retrieving the configuration values.
	 *
	 * @return string Configuration path (mshop/customer/manager/lists/type/typo3/item/)
	 */
	protected function getConfigPath() : string
	{
		return 'mshop/customer/manager/lists/type/typo3/';
	}


	/**
	 * Returns the search configuration for searching items.
	 *
	 * @return array Associative list of search keys and search definitions
	 */
	protected function getSearchConfig() : array
	{
		return $this->searchConfig;
	}
}
